@@ -28,7 +28,7 @@ whose conditions may differ from those of your experiment.
 __docformat__ = 'restructuredtext en'
 __all__ = ['elements', 'neutron_sld','xray_sld',
            'formula','mix_by_weight','mix_by_volume'] # and all elements
-__version__ = "1.3.7"
+__version__ = "1.3.8"
 
 from . import core
 from . import mass
@@ -59,7 +59,7 @@ def data_files():
 
     data_files = [('periodictable-data/xsf',
                    _finddata('xsf', ['*.nff','read.me','f0_WaasKirf.dat'])),
-                  ('periodictable-data', 'activation.dat')]
+                  ('periodictable-data', _finddata('.', ['activation.dat']))]
     return data_files
 
 # Export variables for each element name and symbol.
